@@ -2,17 +2,38 @@
 # -*- coding: utf-8 -*-
 # 
 import os
+import sys
 import util
 import project
 import terminal
+import signal
+from multiprocessing import Pool
+
 import dolly
 
+def init_worker():
+	# Ignore SIGINTs in worker processes.
+	signal.signal(signal.SIGINT, signal.SIG_IGN)
+
+def process_repo(upd, repo):
+	upd.update(repo)
+
 class Update:
 	def visit(self, host):
-		for repo in host.tree:
+		pool = Pool(5, init_worker)
+
+		def pr(repo):
+			return pool.apply_async(process_repo, (self, repo))
+
+		results = zip(host.tree, map(pr, host.tree))
+
+		for r in results:
+			repo, result = r
 			project.Project.currentProj += 1
 			util.printStatus(repo)
-			self.update(repo)
+			# Workaround to Python issue 8296 where a SIGINT will
+			# lock up the process when no wait time is given.
+			result.wait(9999999)
 
 		if host.post_update:
 			util.executeCommand(host.post_update)
@@ -49,4 +70,4 @@ class Update:
 		result = util.executeCommand('git pull --ff-only', cwd=repo['local'])
 
 	def pullSvn(self, repo):
-		result = util.executeCommand('svn update', cwd=repo['local'])
\ No newline at end of file
+		result = util.executeCommand('svn update', cwd=repo['local'])
